.. image:: ../artwork/cicada.png
  :width: 200px
  :align: right

Support
=======

The Cicada documentation:

* http://cicada-mpc.readthedocs.io

Visit our GitHub repository for access to source code, test results, issue tracker, and the wiki:

* http://github.com/cicada-mpc/cicada-mpc

Our coverage statistics are updated automatically when modifications are committed:

* https://coveralls.io/r/cicada-mpc/cicada-mpc

For Cicada questions, comments, or suggestions, get in touch with the team at:

* https://github.com/cicada-mpc/cicada-mpc/discussions

Otherwise, you can contact Tim directly:

* Timothy M. Shead - `tshead@sandia.gov <mailto:tshead@sandia.gov?subject=Cicada>`_
